@@ -34,7 +34,7 @@ try:
 except AttributeError:
     pass
 
-__version__ = '2.0.0'
+__version__ = '2.0.1'
 
 # Magic Number
 GZIP_MAGIC = b'\x1f\x8b'
@@ -247,7 +247,7 @@ class TableDump(Base):
         Decoder for Table_Dump format.
         '''
         self.data['view_number'] = self.val_num(2)
-        self.data['sequence number'] = self.val_num(2)
+        self.data['sequence_number'] = self.val_num(2)
         self.data['prefix'] = self.val_addr(subtype)
         self.data['prefix_length'] = self.val_num(1)
         self.data['status'] = self.val_num(1)
@@ -370,7 +370,7 @@ class AfiSpecRib(Base):
         '''
         Decoder for AFI/SAFI-Specific RIB format.
         '''
-        self.data['sequnce_number'] = self.val_num(4)
+        self.data['sequence_number'] = self.val_num(4)
         self.data['prefix_length'] = self.val_num(1)
         self.data['prefix'] \
             = self.val_addr(af_num.afi, self.data['prefix_length'])
@@ -927,7 +927,7 @@ class BgpAttr(Base):
             path_seg['type'].append(AS_PATH_SEG_T[path_seg['type'][0]])
             path_seg['length'] = self.val_num(1)
             path_seg['value'] = []
-            for _ in range(path_seg['len']):
+            for _ in range(path_seg['length']):
                 path_seg['value'].append(self.val_as(4))
             self.data['value'].append(path_seg)
 
@@ -947,8 +947,7 @@ class BgpAttr(Base):
         self.data['value'] = []
         while self.p < attr_len:
             aigp = collections.OrderedDict()
-            aigp['type'] = [self.val_num(1)]
-            aigp['type'].append(AIGP_T[aigp['type'][0]])
+            aigp['type'] = self.val_num(1)
             aigp['length'] = self.val_num(2)
             aigp['value'] = self.val_num(aigp['length'] - 3)
             self.data['value'].append(aigp)
